# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class CreatePersona(BaseModel):
    create_persona: Optional["CreatePersonaCreatePersona"] = Field(
        alias="createPersona"
    )


class CreatePersonaCreatePersona(BaseModel):
    id: str
    name: str
    state: EntityState
    role: Optional[str]


CreatePersona.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class QueryPersonas(BaseModel):
    personas: Optional["QueryPersonasPersonas"]


class QueryPersonasPersonas(BaseModel):
    results: Optional[list["QueryPersonasPersonasResults"]]


class QueryPersonasPersonasResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryPersonasPersonasResultsOwner"
    state: EntityState
    role: Optional[str]
    instructions: Optional[str]
    facts: Optional[list["QueryPersonasPersonasResultsFacts"]]


class QueryPersonasPersonasResultsOwner(BaseModel):
    id: str


class QueryPersonasPersonasResultsFacts(BaseModel):
    id: Optional[str]
    text: Optional[str]


QueryPersonas.model_rebuild()
QueryPersonasPersonas.model_rebuild()
QueryPersonasPersonasResults.model_rebuild()
